unit AES32; 

// AES32.PAS, Version 6.0 [Delphi for Win32]

interface

const

  AES_BLOCK_SIZE          =  16; {block size of AES is fixed at 16 bytes}
  AES_KEY_SIZE            =  32; {key size is always 32 bytes (for 256-bit AES)}
  AES_GET_CONTROL_VERSION = 101; {get AES control block version}
  AES_GET_CONTROL_SIZE    = 102; {get size of control block}
  AES_GET_VERSION         = 103; {get AES version}
  AES_GET_BUILD           = 104; {get AES build}
  AES_GET_SECURE_SIZE     = 105; {get size of secure random control block}
  AES_GET_REGISTRATION    = 201; {get registration string}
  AES_SET_PAD_BYTE        = 301; {set padding}
  AES_ECB_MODE            =   0; {use ECB mode (default)}
  AES_CBC_MODE            =   2; {use CBC mode}
  AES_ENCRYPT             =   0; {encrypt (default)}
  AES_DECRYPT             =   4; {decrypt}
  AES_PAD_ZERO            =   6; {pad with 0's}
  AES_PAD_SPACE           =   7; {pad with spaces (0x20)}
  AES_PAD_RANDOM          =   8; {pad with random values}
  AES_PAD_PKCS7           =   9; {pad according to PKCS7}
  AES_NIBBLE_METHOD       =   0; {use "nibble" method to create encryption key}
  AES_SHA256_METHOD       =   1; {use SHA 256 to create encryption key}
  AES_MIXED_METHOD        =   2; {do nibble method followed by SHA256 method}
  AES_PKCS7_MASK          =   1; {uses PKCS7 padding if bit = 1}
  AES_SET_SEED            =   1; {set random number generator seed}
  
  {error codes}
  AES_NOT_MULTIPLE        =  -2; {not multiple of 16 bytes}
  AES_BAD_KEY_DIR         =  -3; {key direction is invalid}
  AES_BAD_KEY_DATA        =  -4; {key data is invalid}
  AES_BAD_CIPHER_MODE     =  -5; {invalid cipher mode}
  AES_BAD_CIPHER_STATE    =  -6; {cipher not initialized}
  AES_BAD_BLOCK_LENGTH    =  -7; {invalid block length}
  AES_NOT_INITIALIZED     =  -8; {AES control block not initialized}
  AES_IS_CORRUPTED        =  -9; {AES control block is corrupted}
  AES_INTERNAL_ERROR      = -10; {AES internal error}
  AES_BAD_PASS_LEN        = -11; {password too short}
  AES_CANNOT_OPEN         = -12; {cannot open file (for read)}
  AES_CANNOT_CREATE       = -13; {cannot create file}
  AES_READ_ERROR          = -14; {read error}
  AES_WRITE_ERROR         = -15; {write error}
  AES_BAD_PAD_CHOICE      = -16; {must be AES_PAD_*}
  AES_BAD_HEX_CHAR        = -17; {bad hex character}
  AES_UNEXPECTED_CHAR     = -18; {unexpected character}
  AES_ATTACH_CALL         = -19; {aesAttach not called}
  AES_NULL_POINTER        = -20; {unexpected null pointer}
  AES_BAD_METHOD          = -21; {bad method}
  AES_BUFFER_TOO_SMALL    = -22; {buffer is too small}
  AES_BUFFER_TOO_BIG      = -23; {buffer is too big}
  AES_PKCS7_ERROR         = -24; {PKCS7 padding error}
  AES_CANNOT_OPEN_WRITE   = -25; {cannot open file (for write)}
  AES_CANNOT_CLOSE        = -26; {cannot close file}
  AES_CANNOT_DELETE       = -27; {cannot delete file}

  AES_ABORTED             = -201;  
  AES_KEYCODE             = -202;  
  AES_EXPIRED             = -203;  

function aesAttach(KeyCode:Integer;Flags:Integer):Integer;stdcall;
function aesByteToHex(Buffer:PAnsiChar;BufLen:Integer;HexBuf:PAnsiChar):Integer;stdcall;
function aesDecodeBase64(CodeBuf:PAnsiChar;CodeLen:Integer;DataBuf:PAnsiChar):Integer;stdcall;
function aesDecryptBlocks(Control:PAnsiChar;Data:PAnsiChar;DataLen:Integer;Buffer:PAnsiChar):Integer;stdcall; 
function aesDecryptBuffer(Control:PAnsiChar;InputBuf:PAnsiChar;InputLen:Integer;OutputBuf:PAnsiChar):Integer;stdcall;
function aesDecryptFile(Control:PAnsiChar;InputFile:PAnsiChar;OutputFile:PAnsiChar):Integer;stdcall;
function aesEncodeBase64(DataBuf:PAnsiChar;DataLen:Integer;CodeBuf:PAnsiChar):Integer;stdcall;
function aesEncryptBlocks(Control:PAnsiChar;Data:PAnsiChar;DataLen:Integer;Buffer:PAnsiChar):Integer;stdcall; 
function aesEncryptBuffer(Control:PAnsiChar;InputBuf:PAnsiChar;InputLen:Integer;OutputBuf:PAnsiChar):Integer;stdcall;
function aesEncryptFile(Control:PAnsiChar;InputFile:PAnsiChar;OutputFile:PAnsiChar):Integer;stdcall;
function aesEncryptWrite(Control:PAnsiChar;Data:PAnsiChar;DataLen:Integer;OutputFile:PAnsiChar):Integer;stdcall;   
function aesErrorText(ErrCode:Integer;Buffer:PAnsiChar;BufLen:Integer):Integer;stdcall;
function aesGetInteger(Control:PAnsiChar;ParamName:Integer):Integer;stdcall;
function aesGetString(Control:PAnsiChar;ParamName:Integer;Buffer:PAnsiChar;BufLen:Integer):Integer;stdcall;
function aesHexToByte(HexBuf:PAnsiChar;HexBytes:Integer;ByteBuf:PAnsiChar):Integer;stdcall;
function aesInitAES(KeyBuf:PAnsiChar;Vector:PAnsiChar;Mode:Integer;Direction:Integer;Control:PAnsiChar):Integer;stdcall;
function aesMakeKeyPair(PublicKey:PAnsiChar; PrivateKey:PAnsiChar):Integer;stdcall;
function aesMakeRandom(Buffer:PAnsiChar;BufSize:Integer):Integer;stdcall;
function aesMakeSharedKey(PublicKey:PAnsiChar; PrivateKey:PAnsiChar; SharedKey:PAnsiChar; AES_KEY:PAnsiChar):Integer;stdcall;
function aesMakeUserKey(UserPhrase:PAnsiChar;KeyBuffer:PAnsiChar;Flags:Integer):Integer;stdcall;  
function aesPadBuffer(Buf:PAnsiChar;BufLen:Integer;PadControl:Integer):Integer;stdcall;
function aesReadDecrypt(Control:PAnsiChar;InputFile:PAnsiChar;Buffer:PAnsiChar;BufLen:Integer):Integer;stdcall;
function aesRemovePad(DataBuf:PAnsiChar;DataLen:Integer):Integer;stdcall;
function aesSaltPass(SaltSeed:Integer;NbrSaltChars:Integer;SaltOut:PAnsiChar;PassInp:PAnsiChar;PassOut:PAnsiChar):Integer;stdcall;
function aesSecureRandom(SecureCTX:PAnsiChar;Buffer:PAnsiChar;BufLen:Integer):Integer;stdcall;
function aesSetInteger(Control:PAnsiChar;ParamName:Integer;ParamValue:Integer):Integer;stdcall;
function aesSha256(DataBuf:PAnsiChar;Hash:PAnsiChar):Integer;stdcall;
function aesSha256Data(DataBuf:PAnsiChar;DataLen:Integer;Hash:PAnsiChar):Integer;stdcall;
function aesSha256File(FileName:PAnsiChar;Hash:PAnsiChar):Integer;stdcall;
function aesShredFile(FileName:PAnsiChar;DelFlag:Integer):Integer;stdcall;
function aesSleep(MilliSecs:Integer):Integer;stdcall;
function aesVerifyControl(Control:PAnsiChar):Integer;stdcall;
function aesXorBits(XorBuf:PAnsiChar;XorLen:Integer;InBuf:PAnsiChar;OutBuf:PAnsiChar;BufLen:Integer):Integer;stdcall;

implementation

function aesAttach; external 'aes32.dll';
function aesByteToHex; external 'aes32.dll';
function aesDecodeBase64; external 'aes32.dll';
function aesDecryptBlocks; external 'aes32.dll'; 
function aesDecryptBuffer; external 'aes32.dll';
function aesDecryptFile; external 'aes32.dll';
function aesEncodeBase64; external 'aes32.dll';
function aesEncryptBlocks; external 'aes32.dll';
function aesEncryptBuffer; external 'aes32.dll';
function aesEncryptFile; external 'aes32.dll';
function aesEncryptWrite; external 'aes32.dll';  
function aesErrorText; external 'aes32.dll';
function aesGetInteger; external 'aes32.dll';
function aesGetString; external 'aes32.dll';
function aesHexToByte; external 'aes32.dll'; 
function aesInitAES; external 'aes32.dll';
function aesMakeKeyPair; external 'aes32.dll';
function aesMakeRandom; external 'aes32.dll';
function aesMakeSharedKey; external 'aes32.dll';
function aesMakeUserKey; external 'aes32.dll'; 
function aesPadBuffer; external 'aes32.dll'; 
function aesReadDecrypt; external 'aes32.dll';
function aesRemovePad; external 'aes32.dll';
function aesSaltPass; external 'aes32.dll';
function aesSecureRandom; external 'aes32.dll';
function aesSetInteger; external 'aes32.dll';
function aesSha256; external 'aes32.dll';
function aesSha256Data; external 'aes32.dll';
function aesSha256File; external 'aes32.dll';
function aesShredFile; external 'aes32.dll';
function aesSleep; external 'aes32.dll'; 
function aesVerifyControl; external 'aes32.dll';
function aesXorBits; external 'aes32.dll';
end.




